---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Execute command '....'
3. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Example**
Provide a minimal reproducible example.
You may also provide your FABulous project.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Your Setup (please complete the following information):**
 - OS: [e.g. Debian Linux]
 - OS / kernel version: [e.g. 6.12.4-arch1-1]
 - Python version: [e.g. 3.12.07]
 - Yosys version: [e.g. 0.43]
 - FABulous version / git commit id / git branch

**Additional context**
Add any other context about the problem here.
